#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.fish"), aligned (8)))
#else
# define SECTION
#endif

#ifdef _MSC_VER
static const SECTION union { const guint8 data[2053]; const double alignment; void * const ptr;}  fish_resource_data = { {
  0107, 0126, 0141, 0162, 0151, 0141, 0156, 0164, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 
  0030, 0000, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0000, 0000, 0050, 0010, 0000, 0000, 0000, 
  0000, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 
  0003, 0000, 0000, 0000, 0005, 0000, 0000, 0000, 0007, 0000, 0000, 0000, 0007, 0000, 0000, 0000, 
  0260, 0267, 0044, 0060, 0001, 0000, 0000, 0000, 0000, 0001, 0000, 0000, 0006, 0000, 0114, 0000, 
  0010, 0001, 0000, 0000, 0014, 0001, 0000, 0000, 0113, 0120, 0220, 0013, 0003, 0000, 0000, 0000, 
  0014, 0001, 0000, 0000, 0004, 0000, 0114, 0000, 0020, 0001, 0000, 0000, 0024, 0001, 0000, 0000, 
  0223, 0034, 0234, 0002, 0005, 0000, 0000, 0000, 0024, 0001, 0000, 0000, 0007, 0000, 0166, 0000, 
  0040, 0001, 0000, 0000, 0057, 0007, 0000, 0000, 0324, 0265, 0002, 0000, 0377, 0377, 0377, 0377, 
  0057, 0007, 0000, 0000, 0001, 0000, 0114, 0000, 0060, 0007, 0000, 0000, 0064, 0007, 0000, 0000, 
  0104, 0237, 0231, 0330, 0007, 0000, 0000, 0000, 0064, 0007, 0000, 0000, 0007, 0000, 0114, 0000, 
  0074, 0007, 0000, 0000, 0100, 0007, 0000, 0000, 0275, 0027, 0205, 0252, 0004, 0000, 0000, 0000, 
  0100, 0007, 0000, 0000, 0005, 0000, 0114, 0000, 0110, 0007, 0000, 0000, 0120, 0007, 0000, 0000, 
  0365, 0025, 0023, 0126, 0005, 0000, 0000, 0000, 0120, 0007, 0000, 0000, 0014, 0000, 0166, 0000, 
  0140, 0007, 0000, 0000, 0372, 0007, 0000, 0000, 0157, 0330, 0366, 0224, 0000, 0000, 0000, 0000, 
  0372, 0007, 0000, 0000, 0006, 0000, 0114, 0000, 0000, 0010, 0000, 0000, 0004, 0010, 0000, 0000, 
  0147, 0156, 0157, 0155, 0145, 0057, 0000, 0000, 0007, 0000, 0000, 0000, 0157, 0162, 0147, 0057, 
  0000, 0000, 0000, 0000, 0146, 0151, 0163, 0150, 0056, 0165, 0151, 0000, 0000, 0000, 0000, 0000, 
  0233, 0120, 0000, 0000, 0001, 0000, 0000, 0000, 0170, 0332, 0355, 0134, 0113, 0163, 0333, 0066, 
  0020, 0276, 0347, 0127, 0240, 0270, 0166, 0144, 0231, 0162, 0035, 0073, 0031, 0211, 0231, 0324, 
  0155, 0322, 0103, 0247, 0223, 0151, 0335, 0063, 0007, 0042, 0127, 0022, 0042, 0010, 0140, 0001, 
  0320, 0217, 0137, 0221, 0143, 0377, 0137, 0177, 0111, 0101, 0322, 0017, 0312, 0242, 0370, 0000, 
  0050, 0133, 0162, 0350, 0233, 0251, 0335, 0045, 0366, 0303, 0276, 0200, 0005, 0061, 0376, 0160, 
  0263, 0142, 0350, 0012, 0244, 0242, 0202, 0117, 0260, 0167, 0164, 0214, 0021, 0360, 0120, 0104, 
  0224, 0317, 0047, 0370, 0357, 0313, 0117, 0203, 0163, 0374, 0301, 0177, 0063, 0376, 0141, 0060, 
  0100, 0237, 0201, 0203, 0044, 0032, 0042, 0164, 0115, 0365, 0002, 0315, 0031, 0211, 0000, 0235, 
  0034, 0171, 0347, 0107, 0047, 0150, 0060, 0060, 0104, 0224, 0153, 0220, 0063, 0022, 0202, 0377, 
  0006, 0241, 0261, 0204, 0177, 0022, 0052, 0101, 0041, 0106, 0247, 0023, 0074, 0327, 0313, 0037, 
  0361, 0343, 0213, 0014, 0333, 0010, 0017, 0063, 0072, 0061, 0375, 0012, 0241, 0106, 0041, 0043, 
  0112, 0115, 0360, 0147, 0275, 0374, 0030, 0175, 0115, 0224, 0136, 0001, 0327, 0030, 0321, 0150, 
  0202, 0311, 0303, 0377, 0036, 0116, 0071, 0014, 0117, 0054, 0105, 0014, 0122, 0337, 0042, 0116, 
  0126, 0060, 0301, 0114, 0134, 0203, 0304, 0276, 0067, 0036, 0336, 0377, 0120, 0116, 0227, 0304, 
  0161, 0112, 0067, 0072, 0075, 0255, 0243, 0274, 0042, 0054, 0001, 0354, 0237, 0324, 0321, 0051, 
  0015, 0161, 0100, 0171, 0050, 0041, 0033, 0157, 0375, 0020, 0142, 0062, 0207, 0042, 0303, 0223, 
  0221, 0214, 0207, 0071, 0034, 0155, 0221, 0031, 0125, 0043, 0163, 0174, 0344, 0035, 0257, 0377, 
  0065, 0305, 0312, 0073, 0156, 0010, 0225, 0327, 0026, 0052, 0213, 0061, 0075, 0005, 0317, 0153, 
  0003, 0336, 0057, 0224, 0060, 0061, 0317, 0201, 0233, 0121, 0265, 0010, 0142, 0011, 0063, 0220, 
  0306, 0332, 0101, 0005, 0121, 0376, 0143, 0371, 0153, 0103, 0302, 0203, 0231, 0010, 0023, 0205, 
  0375, 0117, 0204, 0051, 0250, 0033, 0346, 0124, 0310, 0010, 0144, 0160, 0115, 0043, 0275, 0330, 
  0230, 0341, 0115, 0162, 0115, 0065, 0003, 0214, 0264, 0044, 0134, 0061, 0242, 0311, 0224, 0231, 
  0207, 0267, 0220, 0276, 0315, 0014, 0023, 0175, 0171, 0034, 0146, 0255, 0244, 0333, 0030, 0202, 
  0005, 0115, 0241, 0311, 0025, 0332, 0140, 0010, 0027, 0224, 0105, 0050, 0163, 0124, 0116, 0330, 
  0040, 0373, 0327, 0114, 0341, 0124, 0334, 0334, 0351, 0136, 0206, 0334, 0317, 0346, 0327, 0014, 
  0266, 0134, 0350, 0040, 0045, 0037, 0075, 0320, 0227, 0130, 0004, 0125, 0324, 0050, 0201, 0375, 
  0113, 0231, 0154, 0200, 0145, 0003, 0160, 0031, 0217, 0220, 0324, 0330, 0000, 0321, 0046, 0234, 
  0140, 0337, 0304, 0025, 0115, 0103, 0302, 0232, 0060, 0252, 0230, 0204, 0046, 0272, 0231, 0060, 
  0120, 0112, 0135, 0216, 0020, 0011, 0323, 0027, 0005, 0104, 0002, 0051, 0050, 0136, 0012, 0126, 
  0242, 0265, 0340, 0117, 0041, 0053, 0360, 0217, 0326, 0004, 0130, 0240, 0147, 0213, 0340, 0243, 
  0172, 0353, 0317, 0266, 0153, 0221, 0253, 0260, 0000, 0026, 0007, 0323, 0374, 0301, 0123, 0316, 
  0222, 0210, 0103, 0246, 0300, 0112, 0255, 0071, 0370, 0315, 0010, 0332, 0066, 0060, 0153, 0044, 
  0152, 0320, 0260, 0141, 0215, 0140, 0106, 0022, 0246, 0333, 0063, 0113, 0010, 0201, 0136, 0245, 
  0341, 0344, 0136, 0102, 0345, 0144, 0224, 0206, 0135, 0005, 0101, 0302, 0115, 0370, 0140, 0224, 
  0327, 0152, 0136, 0014, 0170, 0353, 0102, 0111, 0270, 0064, 0066, 0136, 0377, 0072, 0270, 0211, 
  0011, 0217, 0054, 0306, 0071, 0243, 0214, 0131, 0260, 0305, 0102, 0321, 0334, 0145, 0217, 0253, 
  0324, 0052, 0035, 0377, 0170, 0130, 0142, 0274, 0066, 0006, 0035, 0011, 0016, 0235, 0030, 0364, 
  0005, 0023, 0355, 0324, 0077, 0070, 0213, 0136, 0020, 0325, 0273, 0303, 0163, 0270, 0203, 0327, 
  0205, 0073, 0224, 0001, 0120, 0256, 0274, 0225, 0342, 0026, 0112, 0157, 0126, 0160, 0341, 0062, 
  0110, 0313, 0024, 0354, 0003, 0217, 0032, 0163, 0325, 0105, 0215, 0022, 0210, 0066, 0340, 0331, 
  0214, 0024, 0025, 0225, 0116, 0132, 0342, 0234, 0276, 0150, 0242, 0156, 0127, 0123, 0072, 0127, 
  0111, 0225, 0225, 0222, 0167, 0356, 0134, 0117, 0024, 0201, 0175, 0213, 0237, 0047, 0122, 0266, 
  0166, 0307, 0126, 0150, 0125, 0042, 0366, 0266, 0222, 0253, 0024, 0264, 0162, 0340, 0176, 0317, 
  0263, 0117, 0012, 0135, 0226, 0210, 0274, 0023, 0134, 0306, 0350, 0000, 0240, 0053, 0210, 0145, 
  0374, 0067, 0204, 0321, 0171, 0165, 0222, 0157, 0233, 0154, 0363, 0335, 0007, 0126, 0053, 0220, 
  0150, 0055, 0251, 0111, 0356, 0240, 0312, 0011, 0212, 0044, 0167, 0057, 0275, 0006, 0072, 0137, 
  0230, 0045, 0165, 0266, 0222, 0115, 0135, 0215, 0105, 0371, 0336, 0104, 0011, 0357, 0260, 0132, 
  0376, 0266, 0024, 0124, 0235, 0206, 0234, 0122, 0221, 0103, 0072, 0262, 0256, 0320, 0052, 0322, 
  0322, 0326, 0112, 0255, 0255, 0345, 0077, 0204, 0214, 0305, 0226, 0220, 0361, 0362, 0126, 0277, 
  0125, 0233, 0206, 0276, 0274, 0115, 0053, 0147, 0315, 0272, 0320, 0156, 0273, 0173, 0372, 0167, 
  0323, 0137, 0303, 0136, 0345, 0013, 0365, 0376, 0340, 0354, 0023, 0216, 0176, 0341, 0344, 0033, 
  0065, 0376, 0121, 0351, 0043, 0066, 0226, 0265, 0226, 0136, 0317, 0016, 0315, 0252, 0132, 0247, 
  0135, 0267, 0364, 0333, 0014, 0344, 0032, 0240, 0323, 0027, 0006, 0305, 0155, 0263, 0035, 0341, 
  0335, 0025, 0346, 0325, 0365, 0335, 0250, 0261, 0210, 0132, 0314, 0152, 0103, 0137, 0206, 0334, 
  0135, 0040, 0251, 0221, 0323, 0021, 0176, 0135, 0142, 0350, 0124, 0355, 0130, 0156, 0063, 0374, 
  0141, 0010, 0220, 0230, 0241, 0164, 0327, 0372, 0275, 0313, 0073, 0322, 0325, 0364, 0212, 0310, 
  0145, 0022, 0273, 0003, 0330, 0152, 0145, 0136, 0057, 0156, 0305, 0141, 0045, 0070, 0015, 0323, 
  0025, 0316, 0034, 0064, 0366, 0063, 0063, 0061, 0141, 0101, 0336, 0066, 0027, 0133, 0227, 0161, 
  0232, 0147, 0236, 0316, 0062, 0120, 0107, 0231, 0250, 0223, 0214, 0324, 0060, 0063, 0065, 0312, 
  0120, 0256, 0001, 0341, 0327, 0164, 0146, 0013, 0001, 0041, 0233, 0351, 0075, 0011, 0010, 0256, 
  0242, 0322, 0315, 0376, 0053, 0242, 0241, 0305, 0326, 0331, 0113, 0331, 0261, 0253, 0252, 0271, 
  0031, 0273, 0112, 0151, 0264, 0015, 0266, 0073, 0053, 0156, 0002, 0167, 0063, 0250, 0273, 0200, 
  0331, 0035, 0142, 0347, 0040, 0321, 0000, 0332, 0132, 0130, 0235, 0252, 0253, 0120, 0254, 0126, 
  0006, 0270, 0276, 0300, 0262, 0051, 0260, 0356, 0301, 0353, 0153, 0254, 0346, 0065, 0326, 0205, 
  0010, 0062, 0320, 0220, 0026, 0110, 0046, 0034, 0135, 0057, 0200, 0033, 0164, 0151, 0270, 0204, 
  0350, 0375, 0076, 0227, 0111, 0367, 0223, 0335, 0127, 0112, 0337, 0101, 0245, 0264, 0066, 0331, 
  0175, 0261, 0324, 0027, 0113, 0175, 0261, 0264, 0303, 0142, 0311, 0173, 0256, 0142, 0151, 0167, 
  0033, 0245, 0266, 0273, 0172, 0355, 0140, 0164, 0202, 0320, 0176, 0233, 0264, 0373, 0136, 0213, 
  0115, 0323, 0240, 0071, 0124, 0326, 0060, 0265, 0357, 0264, 0164, 0167, 0022, 0242, 0155, 0373, 
  0265, 0031, 0034, 0373, 0163, 0054, 0250, 0270, 0161, 0176, 0336, 0367, 0245, 0333, 0167, 0347, 
  0014, 0156, 0336, 0041, 0264, 0244, 0037, 0327, 0142, 0336, 0316, 0373, 0172, 0243, 0103, 0353, 
  0300, 0264, 0132, 0135, 0065, 0137, 0125, 0175, 0344, 0164, 0225, 0131, 0155, 0243, 0045, 0124, 
  0203, 0326, 0275, 0153, 0373, 0276, 0111, 0013, 0277, 0157, 0135, 0076, 0153, 0353, 0362, 0102, 
  0254, 0246, 0302, 0104, 0223, 0113, 0270, 0271, 0373, 0252, 0301, 0330, 0314, 0034, 0202, 0060, 
  0175, 0156, 0202, 0213, 0116, 0237, 0357, 0265, 0073, 0365, 0345, 0333, 0236, 0224, 0157, 0016, 
  0107, 0145, 0334, 0352, 0267, 0175, 0072, 0051, 0163, 0366, 0052, 0117, 0312, 0234, 0035, 0346, 
  0111, 0231, 0262, 0244, 0330, 0037, 0236, 0331, 0347, 0303, 0063, 0357, 0372, 0303, 0063, 0273, 
  0077, 0074, 0243, 0142, 0200, 0276, 0271, 0143, 0325, 0334, 0311, 0241, 0353, 0133, 0073, 0055, 
  0216, 0317, 0174, 0041, 0211, 0002, 0144, 0210, 0321, 0114, 0032, 0332, 0275, 0156, 0347, 0344, 
  0323, 0253, 0142, 0312, 0373, 0136, 0316, 0053, 0354, 0345, 0374, 0145, 0046, 0266, 0370, 0045, 
  0332, 0343, 0164, 0277, 0222, 0156, 0016, 0345, 0167, 0243, 0012, 0302, 0005, 0221, 0330, 0377, 
  0357, 0337, 0157, 0116, 0315, 0241, 0307, 0017, 0336, 0375, 0302, 0307, 0356, 0116, 0312, 0062, 
  0272, 0232, 0006, 0351, 0075, 0006, 0305, 0117, 0320, 0275, 0237, 0336, 0271, 0010, 0215, 0350, 
  0234, 0152, 0325, 0252, 0043, 0263, 0051, 0204, 0047, 0053, 0220, 0064, 0334, 0337, 0376, 0327, 
  0376, 0271, 0277, 0167, 0130, 0356, 0277, 0221, 0307, 0215, 0046, 0272, 0117, 0346, 0055, 0222, 
  0271, 0202, 0120, 0360, 0110, 0365, 0335, 0341, 0172, 0337, 0030, 0275, 0316, 0356, 0260, 0123, 
  0315, 0156, 0021, 0200, 0366, 0240, 0077, 0154, 0267, 0332, 0272, 0130, 0100, 0270, 0366, 0331, 
  0273, 0024, 0146, 0231, 0010, 0201, 0026, 0363, 0171, 0032, 0065, 0336, 0164, 0343, 0221, 0301, 
  0237, 0231, 0130, 0044, 0070, 0272, 0137, 0175, 0042, 0063, 0123, 0300, 0224, 0055, 0302, 0135, 
  0257, 0362, 0134, 0304, 0130, 0174, 0302, 0276, 0243, 0345, 0303, 0326, 0100, 0173, 0164, 0152, 
  0053, 0042, 0222, 0344, 0072, 0240, 0074, 0062, 0163, 0246, 0205, 0154, 0063, 0234, 0357, 0311, 
  0315, 0117, 0372, 0143, 0040, 0375, 0061, 0220, 0376, 0030, 0310, 0363, 0036, 0003, 0071, 0334, 
  0353, 0060, 0332, 0134, 0006, 0121, 0253, 0157, 0375, 0275, 0026, 0353, 0072, 0256, 0375, 0070, 
  0316, 0057, 0235, 0032, 0344, 0173, 0113, 0017, 0275, 0356, 0365, 0307, 0110, 0202, 0212, 0005, 
  0127, 0146, 0064, 0003, 0317, 0303, 0176, 0341, 0262, 0247, 0361, 0160, 0215, 0262, 0236, 0377, 
  0024, 0373, 0205, 0253, 0165, 0112, 0331, 0237, 0074, 0124, 0353, 0327, 0266, 0215, 0207, 0205, 
  0053, 0004, 0377, 0007, 0047, 0304, 0022, 0351, 0000, 0050, 0165, 0165, 0141, 0171, 0051, 0057, 
  0001, 0000, 0000, 0000, 0141, 0160, 0160, 0154, 0145, 0164, 0057, 0000, 0005, 0000, 0000, 0000, 
  0146, 0151, 0163, 0150, 0057, 0000, 0000, 0000, 0006, 0000, 0000, 0000, 0002, 0000, 0000, 0000, 
  0146, 0151, 0163, 0150, 0055, 0155, 0145, 0156, 0165, 0056, 0165, 0151, 0000, 0000, 0000, 0000, 
  0366, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0170, 0332, 0165, 0117, 0313, 0016, 0303, 0040, 
  0014, 0073, 0217, 0257, 0100, 0271, 0157, 0375, 0001, 0312, 0067, 0354, 0027, 0002, 0163, 0065, 
  0044, 0140, 0023, 0244, 0207, 0375, 0375, 0170, 0110, 0355, 0251, 0067, 0333, 0211, 0023, 0333, 
  0204, 0054, 0050, 0033, 0173, 0130, 0245, 0265, 0111, 0310, 0273, 0016, 0257, 0225, 0266, 0120, 
  0337, 0367, 0316, 0250, 0353, 0155, 0122, 0341, 0045, 0174, 0262, 0125, 0267, 0101, 0203, 0040, 
  0065, 0074, 0011, 0213, 0224, 0340, 0166, 0201, 0316, 0234, 0260, 0122, 0144, 0207, 0110, 0132, 
  0012, 0347, 0032, 0131, 0330, 0305, 0046, 0376, 0120, 0311, 0076, 0013, 0066, 0024, 0144, 0217, 
  0152, 0226, 0303, 0166, 0171, 0210, 0307, 0117, 0262, 0075, 0315, 0343, 0173, 0345, 0035, 0326, 
  0145, 0046, 0232, 0370, 0010, 0333, 0111, 0157, 0141, 0125, 0133, 0070, 0233, 0376, 0001, 0227, 
  0166, 0116, 0030, 0000, 0050, 0165, 0165, 0141, 0171, 0051, 0160, 0141, 0156, 0145, 0154, 0057, 
  0004, 0000, 0000, 0000
} };
#else /* _MSC_VER */
static const SECTION union { const guint8 data[2053]; const double alignment; void * const ptr;}  fish_resource_data = {
  "\107\126\141\162\151\141\156\164\000\000\000\000\000\000\000\000"
  "\030\000\000\000\000\001\000\000\000\000\000\050\010\000\000\000"
  "\000\000\000\000\001\000\000\000\001\000\000\000\001\000\000\000"
  "\003\000\000\000\005\000\000\000\007\000\000\000\007\000\000\000"
  "\260\267\044\060\001\000\000\000\000\001\000\000\006\000\114\000"
  "\010\001\000\000\014\001\000\000\113\120\220\013\003\000\000\000"
  "\014\001\000\000\004\000\114\000\020\001\000\000\024\001\000\000"
  "\223\034\234\002\005\000\000\000\024\001\000\000\007\000\166\000"
  "\040\001\000\000\057\007\000\000\324\265\002\000\377\377\377\377"
  "\057\007\000\000\001\000\114\000\060\007\000\000\064\007\000\000"
  "\104\237\231\330\007\000\000\000\064\007\000\000\007\000\114\000"
  "\074\007\000\000\100\007\000\000\275\027\205\252\004\000\000\000"
  "\100\007\000\000\005\000\114\000\110\007\000\000\120\007\000\000"
  "\365\025\023\126\005\000\000\000\120\007\000\000\014\000\166\000"
  "\140\007\000\000\372\007\000\000\157\330\366\224\000\000\000\000"
  "\372\007\000\000\006\000\114\000\000\010\000\000\004\010\000\000"
  "\147\156\157\155\145\057\000\000\007\000\000\000\157\162\147\057"
  "\000\000\000\000\146\151\163\150\056\165\151\000\000\000\000\000"
  "\233\120\000\000\001\000\000\000\170\332\355\134\113\163\333\066"
  "\020\276\347\127\240\270\166\144\231\162\035\073\031\211\231\324"
  "\155\322\103\247\223\151\335\063\007\042\127\022\042\010\140\001"
  "\320\217\137\221\143\377\137\177\111\101\322\017\312\242\370\000"
  "\050\133\162\350\233\251\335\045\366\303\276\200\005\061\376\160"
  "\263\142\350\012\244\242\202\117\260\167\164\214\021\360\120\104"
  "\224\317\047\370\357\313\117\203\163\374\301\177\063\376\141\060"
  "\100\237\201\203\044\032\042\164\115\365\002\315\031\211\000\235"
  "\034\171\347\107\047\150\060\060\104\224\153\220\063\022\202\377"
  "\006\241\261\204\177\022\052\101\041\106\247\023\074\327\313\037"
  "\361\343\213\014\333\010\017\063\072\061\375\012\241\106\041\043"
  "\112\115\360\147\275\374\030\175\115\224\136\001\327\030\321\150"
  "\202\311\303\377\036\116\071\014\117\054\105\014\122\337\042\116"
  "\126\060\301\114\134\203\304\276\067\036\336\377\120\116\227\304"
  "\161\112\067\072\075\255\243\274\042\054\001\354\237\324\321\051"
  "\015\161\100\171\050\041\033\157\375\020\142\062\207\042\303\223"
  "\221\214\207\071\034\155\221\031\125\043\163\174\344\035\257\377"
  "\065\305\312\073\156\010\225\327\026\052\213\061\075\005\317\153"
  "\003\336\057\224\060\061\317\201\233\121\265\010\142\011\063\220"
  "\306\332\101\005\121\376\143\371\153\103\302\203\231\010\023\205"
  "\375\117\204\051\250\033\346\124\310\010\144\160\115\043\275\330"
  "\230\341\115\162\115\065\003\214\264\044\134\061\242\311\224\231"
  "\207\267\220\276\315\014\023\175\171\034\146\255\244\333\030\202"
  "\005\115\241\311\025\332\140\010\027\224\105\050\163\124\116\330"
  "\040\373\327\114\341\124\334\334\351\136\206\334\317\346\327\014"
  "\266\134\350\040\045\037\075\320\227\130\004\125\324\050\201\375"
  "\113\231\154\200\145\003\160\031\217\220\324\330\000\321\046\234"
  "\140\337\304\025\115\103\302\232\060\252\230\204\046\272\231\060"
  "\120\112\135\216\020\011\323\027\005\104\002\051\050\136\012\126"
  "\242\265\340\117\041\053\360\217\326\004\130\240\147\213\340\243"
  "\172\353\317\266\153\221\253\260\000\026\007\323\374\301\123\316"
  "\222\210\103\246\300\112\255\071\370\315\010\332\066\060\153\044"
  "\152\320\260\141\215\140\106\022\246\333\063\113\010\201\136\245"
  "\341\344\136\102\345\144\224\206\135\005\101\302\115\370\140\224"
  "\327\152\136\014\170\353\102\111\270\064\066\136\377\072\270\211"
  "\011\217\054\306\071\243\214\131\260\305\102\321\334\145\217\253"
  "\324\052\035\377\170\130\142\274\066\006\035\011\016\235\030\364"
  "\005\023\355\324\077\070\213\136\020\325\273\303\163\270\203\327"
  "\205\073\224\001\120\256\274\225\342\026\112\157\126\160\341\062"
  "\110\313\024\354\003\217\032\163\325\105\215\022\210\066\340\331"
  "\214\024\025\225\116\132\342\234\276\150\242\156\127\123\072\127"
  "\111\225\225\222\167\356\134\117\024\201\175\213\237\047\122\266"
  "\166\307\126\150\125\042\366\266\222\253\024\264\162\340\176\317"
  "\263\117\012\135\226\210\274\023\134\306\350\000\240\053\210\145"
  "\374\067\204\321\171\165\222\157\233\154\363\335\007\126\053\220"
  "\150\055\251\111\356\240\312\011\212\044\167\057\275\006\072\137"
  "\230\045\165\266\222\115\135\215\105\371\336\104\011\357\260\132"
  "\376\266\024\124\235\206\234\122\221\103\072\262\256\320\052\322"
  "\322\326\112\255\255\345\077\204\214\305\226\220\361\362\126\277"
  "\125\233\206\276\274\115\053\147\315\272\320\156\273\173\372\167"
  "\323\137\303\136\345\013\365\376\340\354\023\216\176\341\344\033"
  "\065\376\121\351\043\066\226\265\226\136\317\016\315\252\132\247"
  "\135\267\364\333\014\344\032\240\323\027\006\305\155\263\035\341"
  "\335\025\346\325\365\335\250\261\210\132\314\152\103\137\206\334"
  "\135\040\251\221\323\021\176\135\142\350\124\355\130\156\063\374"
  "\141\010\220\230\241\164\327\372\275\313\073\322\325\364\212\310"
  "\145\022\273\003\330\152\145\136\057\156\305\141\045\070\015\323"
  "\025\316\034\064\366\063\063\061\141\101\336\066\027\133\227\161"
  "\232\147\236\316\062\120\107\231\250\223\214\324\060\063\065\312"
  "\120\256\001\341\327\164\146\013\001\041\233\351\075\011\010\256"
  "\242\322\315\376\053\242\241\305\326\331\113\331\261\253\252\271"
  "\031\273\112\151\264\015\266\073\053\156\002\167\063\250\273\200"
  "\331\035\142\347\040\321\000\332\132\130\235\252\253\120\254\126"
  "\006\270\276\300\262\051\260\356\301\353\153\254\346\065\326\205"
  "\010\062\320\220\026\110\046\034\135\057\200\033\164\151\270\204"
  "\350\375\076\227\111\367\223\335\127\112\337\101\245\264\066\331"
  "\175\261\324\027\113\175\261\264\303\142\311\173\256\142\151\167"
  "\033\245\266\273\172\355\140\164\202\320\176\233\264\373\136\213"
  "\115\323\240\071\124\326\060\265\357\264\164\167\022\242\155\373"
  "\265\031\034\373\163\054\250\270\161\176\336\367\245\333\167\347"
  "\014\156\336\041\264\244\037\327\142\336\316\373\172\243\103\353"
  "\300\264\132\135\065\137\125\175\344\164\225\131\155\243\045\124"
  "\203\326\275\153\373\276\111\013\277\157\135\076\153\353\362\102"
  "\254\246\302\104\223\113\270\271\373\252\301\330\314\034\202\060"
  "\175\156\202\213\116\237\357\265\073\365\345\333\236\224\157\016"
  "\107\145\334\352\267\175\072\051\163\366\052\117\312\234\035\346"
  "\111\231\262\244\330\037\236\331\347\303\063\357\372\303\063\273"
  "\077\074\243\142\200\276\271\143\325\334\311\241\353\133\073\055"
  "\216\317\174\041\211\002\144\210\321\114\032\332\275\156\347\344"
  "\323\253\142\312\373\136\316\053\354\345\374\145\046\266\370\045"
  "\332\343\164\277\222\156\016\345\167\243\012\302\005\221\330\377"
  "\357\337\157\116\315\241\307\017\336\375\302\307\356\116\312\062"
  "\272\232\006\351\075\006\305\117\320\275\237\336\271\010\215\350"
  "\234\152\325\252\043\263\051\204\047\053\220\064\334\337\376\327"
  "\376\271\277\167\130\356\277\221\307\215\046\272\117\346\055\222"
  "\271\202\120\360\110\365\335\341\172\337\030\275\316\356\260\123"
  "\315\156\021\200\366\240\077\154\267\332\272\130\100\270\366\331"
  "\273\024\146\231\010\201\026\363\171\032\065\336\164\343\221\301"
  "\237\231\130\044\070\272\137\175\042\063\123\300\224\055\302\135"
  "\257\362\134\304\130\174\302\276\243\345\303\326\100\173\164\152"
  "\053\042\222\344\072\240\074\062\163\246\205\154\063\234\357\311"
  "\315\117\372\143\040\375\061\220\376\030\310\363\036\003\071\334"
  "\353\060\332\134\006\121\253\157\375\275\026\353\072\256\375\070"
  "\316\057\235\032\344\173\113\017\275\356\365\307\110\202\212\005"
  "\127\146\064\003\317\303\176\341\262\247\361\160\215\262\236\377"
  "\024\373\205\253\165\112\331\237\074\124\353\327\266\215\207\205"
  "\053\004\377\007\047\304\022\351\000\050\165\165\141\171\051\057"
  "\001\000\000\000\141\160\160\154\145\164\057\000\005\000\000\000"
  "\146\151\163\150\057\000\000\000\006\000\000\000\002\000\000\000"
  "\146\151\163\150\055\155\145\156\165\056\165\151\000\000\000\000"
  "\366\000\000\000\001\000\000\000\170\332\165\117\313\016\303\040"
  "\014\073\217\257\100\271\157\375\001\312\067\354\027\002\163\065"
  "\044\140\023\244\207\375\375\170\110\355\251\067\333\211\023\333"
  "\204\054\050\033\173\130\245\265\111\310\273\016\257\225\266\120"
  "\337\367\316\250\353\155\122\341\045\174\262\125\267\101\203\040"
  "\065\074\011\213\224\340\166\201\316\234\260\122\144\207\110\132"
  "\012\347\032\131\330\305\046\376\120\311\076\013\066\024\144\217"
  "\152\226\303\166\171\210\307\117\262\075\315\343\173\345\035\326"
  "\145\046\232\370\010\333\111\157\141\125\133\070\233\376\001\227"
  "\166\116\030\000\050\165\165\141\171\051\160\141\156\145\154\057"
  "\004\000\000\000" };
#endif /* !_MSC_VER */

static GStaticResource static_resource = { fish_resource_data.data, sizeof (fish_resource_data.data) - 1 /* nul terminator */, NULL, NULL, NULL };

G_MODULE_EXPORT
GResource *fish_get_resource (void);
GResource *fish_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a usable way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#ifndef __GTK_DOC_IGNORE__

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER) && (_MSC_VER >= 1500)
/* Visual studio 2008 and later has _Pragma */

#include <stdlib.h>

#define G_HAS_CONSTRUCTORS 1

/* We do some weird things to avoid the constructors being optimized
 * away on VS2015 if WholeProgramOptimization is enabled. First we
 * make a reference to the array from the wrapper to make sure its
 * references. Then we use a pragma to make sure the wrapper function
 * symbol is always included at the link stage. Also, the symbols
 * need to be extern (but not dllexport), even though they are not
 * really used from another object file.
 */

/* We need to account for differences between the mangling of symbols
 * for x86 and x64/ARM/ARM64 programs, as symbols on x86 are prefixed
 * with an underscore but symbols on x64/ARM/ARM64 are not.
 */
#ifdef _M_IX86
#define G_MSVC_SYMBOL_PREFIX "_"
#else
#define G_MSVC_SYMBOL_PREFIX ""
#endif

#define G_DEFINE_CONSTRUCTOR(_func) G_MSVC_CTOR (_func, G_MSVC_SYMBOL_PREFIX)
#define G_DEFINE_DESTRUCTOR(_func) G_MSVC_DTOR (_func, G_MSVC_SYMBOL_PREFIX)

#define G_MSVC_CTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _wrapper(void) { _func(); g_slist_find (NULL,  _array ## _func); return 0; } \
  __pragma(comment(linker,"/include:" _sym_prefix # _func "_wrapper")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _wrapper;

#define G_MSVC_DTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _constructor(void) { atexit (_func); g_slist_find (NULL,  _array ## _func); return 0; } \
   __pragma(comment(linker,"/include:" _sym_prefix # _func "_constructor")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _constructor;

#elif defined (_MSC_VER)

#define G_HAS_CONSTRUCTORS 1

/* Pre Visual studio 2008 must use #pragma section */
#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (*p)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif

#endif /* __GTK_DOC_IGNORE__ */

#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(fishresource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(fishresource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(fishresource_destructor)
#endif
G_DEFINE_DESTRUCTOR(fishresource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void fishresource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void fishresource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}
